@@ -5,9 +5,10 @@
 from typing import Annotated, Optional
 
 from fastapi import Query, Depends
-from pydantic import BaseModel, Field, constr
+from pydantic import BaseModel, Field, constr, field_validator
 
 from core.base_params import PaginateParams
+from exceptions.custom_exception import ParamsError
 
 
 class UserQueryParams:
@@ -25,6 +26,13 @@ class UserCreateModel(BaseModel):
     nickname: str = Field(description='昵称')
     email: Optional[str] = None
 
+    @field_validator('username', mode='after')
+    @classmethod
+    def name_validator(cls, name: str):
+        if ' ' in name:
+            raise ParamsError("名称不能包含空格")
+        return name
+
     class Config:
         orm_mode = True
 
