@@ -16,7 +16,7 @@ sys.path.insert(0, BASE_DIR)
 ENV = os.getenv("ENV", 'dev')
 TZ = pytz.timezone(os.getenv("TZ", "Asia/Shanghai"))
 # [REDIS]
-REDIS_HOST = os.getenv("REDIS_HOST", "redis")
+REDIS_HOST = os.getenv("REDIS_HOST", "127.0.0.1")
 REDIS_PORT = os.getenv("REDIS_PORT", "6379")
 REDIS_CACHE_DB = os.getenv("REDIS_CACHE_DB", 0)
 REDIS_PASSWORD = os.getenv("REDIS_PASSWORD", "123456")
@@ -40,6 +40,7 @@ LOG_DIR = os.getenv("LOG_DIR", "log")
 SECRET_KEY = os.getenv("SECRET_KEY", "")
 TOKEN_EXPIRE_SECONDS = int(os.getenv("TOKEN_EXPIRE_SECONDS", 3600 * 24 * 7))
 USE_GUNICORN_WORKER = int(os.getenv("USE_GUNICORN_WORKER", 0))
+SYNC_THREAD_COUNT = int(os.getenv("SYNC_THREAD_COUNT", 800))
 # 根据开发环境导入不同配置文件
 try:
     if ENV.lower() != "prod":
